@@ -6,12 +6,15 @@ The LaunchPad manages the FireWorks database.
 import datetime
 import os
 import time
+
+from pymongo.mongo_client import MongoClient
+from pymongo import DESCENDING
+
 from fireworks.core.fw_config import FWConfig
 from fireworks.utilities.fw_serializers import FWSerializable
-from pymongo.mongo_client import MongoClient
 from fireworks.core.firework import FireWork, Launch, Workflow
-from pymongo import DESCENDING
-from fireworks.utilities.fw_utilities import get_fw_logger, log_exception
+from fireworks.utilities.fw_utilities import get_fw_logger
+
 
 __author__ = 'Anubhav Jain'
 __copyright__ = 'Copyright 2013, The Materials Project'
@@ -390,13 +393,13 @@ class LaunchPad(FWSerializable):
                 m_fw = self.fireworks.find_and_modify(m_query, {'$set': {'state': 'RESERVED'}},
                                                       sort=[("spec._priority", DESCENDING)])
             else:
-                m_fw = self.fireworks.find_one(m_query, {'fw_id': 1},
+                m_fw = self.fireworks.find_one(m_query, {'fw_id': 1, 'spec': 1},
                                                sort=[("spec._priority", DESCENDING)])
-
+                
             if not m_fw:
                 return None
-            m_fw = self.get_fw_by_id(m_fw['fw_id'])
 
+            m_fw = self.get_fw_by_id(m_fw['fw_id'])
             if self._check_fw_for_uniqueness(m_fw):
                 return m_fw
 
@@ -443,7 +446,7 @@ class LaunchPad(FWSerializable):
         return bad_launch_ids
 
     def mark_fizzled(self, launch_id):
-        # TODO: this seems a lot like the code in _complete_launch...DRY
+        # TODO: this seems a lot like the code in complete_launch...DRY
 
         # Do a confirmed write and make sure state_history is preserved
         m_launch = self.get_launch_by_id(launch_id)
@@ -474,7 +477,7 @@ class LaunchPad(FWSerializable):
         m_launch.set_reservation_id(reservation_id)
         self.launches.find_and_modify({'launch_id': launch_id}, m_launch.to_db_dict())
 
-    def _checkout_fw(self, fworker, launch_dir, fw_id=None, host=None, ip=None):
+    def checkout_fw(self, fworker, launch_dir, fw_id=None, host=None, ip=None):
         """
         (internal method) Finds a FireWork that's ready to be run, marks it as running,
         and returns it to the caller. The caller is responsible for running the FireWork.
@@ -536,7 +539,7 @@ class LaunchPad(FWSerializable):
         m_launch.launch_dir = launch_dir
         self._upsert_launch(m_launch)
 
-    def _complete_launch(self, launch_id, action, state='COMPLETED'):
+    def complete_launch(self, launch_id, action, state='COMPLETED'):
         """
         (internal method) used to mark a FireWork's Launch as completed.
         :param launch_id:
@@ -553,7 +556,7 @@ class LaunchPad(FWSerializable):
             fw_id = fw['fw_id']
             self._refresh_wf(self.get_wf_by_fw_id(fw_id), fw_id)
 
-    def _ping_launch(self, launch_id):
+    def ping_launch(self, launch_id):
         m_launch = self.get_launch_by_id(launch_id)
         m_launch.touch_history()
         self.launches.find_and_modify({'launch_id': launch_id, 'state': 'RUNNING'},
@@ -646,4 +649,8 @@ class LaunchPad(FWSerializable):
     def _upsert_launch(self, m_launch):
         # Do a confirmed write of Launch
         # TODO: this no longer needs to be its own function (much was removed)
-        self.launches.find_and_modify({'launch_id': m_launch.launch_id}, m_launch.to_db_dict(), upsert=True)
\ No newline at end of file
+        self.launches.find_and_modify({'launch_id': m_launch.launch_id}, m_launch.to_db_dict(), upsert=True)
+
+    def get_logdir(self):
+        # AJ: This is needed for job packing due to Proxy objects not being fully featured...
+        return self.logdir
\ No newline at end of file
